"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.default = void 0;

var _axios = _interopRequireDefault(require("axios"));

var _qs = _interopRequireDefault(require("qs"));

var _reactNativeRsaNative = require("react-native-rsa-native");

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

async function requestCardHashKey(encryptionKey) {
  const {
    data: {
      id,
      public_key: publicKey
    }
  } = await _axios.default.get('https://api.pagar.me/1/transactions/card_hash_key', {
    params: {
      encryption_key: encryptionKey
    }
  });
  return {
    id,
    publicKey
  };
}

function generateQueryString(card) {
  return _qs.default.stringify({
    card_number: card.number.replace(/[^0-9]/g, ''),
    card_holder_name: card.holderName,
    card_expiration_date: card.expirationDate.replace(/[^0-9]/g, ''),
    card_cvv: card.cvv.replace(/[^0-9]/g, '')
  });
}

async function generateCardHash(card, encryptionKey) {
  const cardHashKey = await requestCardHashKey(encryptionKey);
  const queryString = generateQueryString(card);
  const encrypted = await _reactNativeRsaNative.RSA.encrypt(queryString, cardHashKey.publicKey);
  return "".concat(cardHashKey.id, "_").concat(encrypted);
}

var _default = generateCardHash;
exports.default = _default;
//# sourceMappingURL=index.js.map